/* BdfServer - Copyright (c) 2013-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.interaction;

import fr.exemole.bdfserver.tools.instruction.BdfErrors;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.mapeadores.util.logging.ErrorMessageException;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.StringUtils;
import net.mapeadores.util.text.tableparser.CsvParameters;
import net.mapeadores.util.text.tableparser.SheetCopyParameters;
import net.mapeadores.util.text.tableparser.TableParser;


/**
 *
 * @author Vincent Calame
 */
public class TableParserParametersParser {

    public final static String PARSETYPE_PARAMNAME = "parsetype";
    public final static String SHEETCOPY_PARAMVALUE = "sheetcopy";
    public final static String CSV_PARAMVALUE = "csv";
    public final static String CSV_DELIMITER_PARAMNAME = "csv_delimiter";
    public final static String CSV_QUOTE_PARAMNAME = "csv_quote";
    public final static String CSV_ESCAPED_PARAMNAME = "csv_escaped";

    private TableParserParametersParser() {
    }

    public static TableParser.Parameters parse(RequestMap requestMap) throws ErrorMessageException {
        String parseType = BdfInstructionUtils.getMandatoryParameter(requestMap, PARSETYPE_PARAMNAME);
        TableParser.Parameters params = null;
        if (parseType.equals(SHEETCOPY_PARAMVALUE)) {
            params = new SheetCopyParameters();
        } else if (parseType.equals(CSV_PARAMVALUE)) {
            CsvParameters csvParameters = new CsvParameters();
            String delimParam = requestMap.getParameter(CSV_DELIMITER_PARAMNAME);
            if (delimParam != null) {
                try {
                    char delim = StringUtils.stringToChar(delimParam);
                    csvParameters.setDelimiter(delim);
                } catch (IllegalArgumentException iae) {
                    throw BdfErrors.wrongParameterValue(CSV_DELIMITER_PARAMNAME, delimParam);
                }
            }
            String quoteParam = requestMap.getParameter(CSV_QUOTE_PARAMNAME);
            if (quoteParam != null) {
                try {
                    char quote = StringUtils.stringToChar(quoteParam);
                    csvParameters.setQuote(quote);
                } catch (IllegalArgumentException iae) {
                    throw BdfErrors.wrongParameterValue(CSV_QUOTE_PARAMNAME, quoteParam);
                }
            }
            csvParameters.setEscapedCSV(requestMap.isTrue(CSV_ESCAPED_PARAMNAME));
            params = csvParameters;
        } else {
            throw BdfErrors.wrongParameterValue(PARSETYPE_PARAMNAME, parseType);
        }
        return params;
    }

}
